(function(global, factory) {
  typeof exports === "object" && typeof module !== "undefined" ? factory(exports) : typeof define === "function" && define.amd ? define(["exports"], factory) : (global = typeof globalThis !== "undefined" ? globalThis : global || self, factory(global["json-highlight-api"] = {}));
})(this, function(exports2) {
  "use strict";
  const defaultColors = {
    key: "#9cdcfe",
    literal: "#569cd6",
    number: "#b5cea8",
    string: "#ce9178"
  };
  const jsonLiterals = [
    "true",
    "false",
    "null"
  ];
  function highlightColorKey(str) {
    return `json-highlight-${str}`;
  }
  function injectHighlight(options) {
    const style = document.createElement("style");
    const colors = { ...defaultColors, ...options == null ? void 0 : options.colors };
    for (const [key, color] of Object.entries(colors)) {
      style.innerHTML += `::highlight(${highlightColorKey(
        key
      )}) { color: ${color}; }
`;
    }
    return {
      style,
      destroy: () => destroyHighlight(style)
    };
  }
  function destroyHighlight(style) {
    style == null ? void 0 : style.remove();
    for (const color of Object.keys(defaultColors)) {
      const colorKey = highlightColorKey(color);
      CSS.highlights.delete(colorKey);
    }
  }
  function createRange(node, indexes) {
    const range = new Range();
    range.setStart(node, indexes.start);
    range.setEnd(node, indexes.end);
    return range;
  }
  function highlightJson(node) {
    const treeWalker = document.createTreeWalker(node, NodeFilter.SHOW_TEXT);
    const textNode = treeWalker.nextNode();
    if (!(textNode == null ? void 0 : textNode.textContent)) {
      throw new Error("Node has no text content");
    }
    const text = textNode.textContent;
    const matches = text.matchAll(
      /("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+]?\d+)?)/g
    );
    const jsonRanges = {};
    for (const match of matches) {
      const value = match[0];
      if (!value || match.index === void 0)
        continue;
      const indexes = {
        start: match.index,
        end: match.index + value.length
      };
      let rangeType = "";
      if (value.endsWith(":")) {
        rangeType = "key";
        indexes.end -= 1;
      }
      if (value.endsWith('"')) {
        rangeType = "string";
      }
      if (!isNaN(parseFloat(value))) {
        rangeType = "number";
      }
      if (jsonLiterals.includes(value)) {
        rangeType = "literal";
      }
      if (rangeType) {
        const range = createRange(textNode, indexes);
        jsonRanges[rangeType] ?? (jsonRanges[rangeType] = []);
        jsonRanges[rangeType].push(range);
      }
    }
    for (const [color, ranges] of Object.entries(jsonRanges)) {
      const colorKey = highlightColorKey(color);
      if (CSS.highlights.has(colorKey)) {
        const actualHighlights = CSS.highlights.get(colorKey);
        for (const range of ranges) {
          actualHighlights.add(range);
        }
      } else {
        const highlight = new Highlight(...ranges);
        CSS.highlights.set(highlightColorKey(color), highlight);
      }
    }
  }
  exports2.highlightJson = highlightJson;
  exports2.injectHighlight = injectHighlight;
  Object.defineProperty(exports2, Symbol.toStringTag, { value: "Module" });
});
//# sourceMappingURL=json-highlight-api.umd.cjs.map
